@@ -1,6 +1,4 @@
 
-context("async_filter")
-
 test_that("async_filter", {
 
   is_odd <- function(x) {
@@ -39,8 +37,6 @@ test_that("async_filter, errors", {
   expect_false(called)
 })
 
-context("async_reject")
-
 test_that("async_reject", {
 
   is_even <- function(x) {
