@@ -21,7 +21,8 @@ test_that("get_cache_files", {
       sort(names(files$pkgs)),
       sort(c("path", "etag", "basedir", "base", "mirror", "url",
              "fallback_url", "platform", "r_version", "type",
-             "bioc_version", "meta_path", "meta_etag", "meta_url"
+             "bioc_version", "meta_path", "meta_etag", "meta_url",
+             "bin_path", "bin_etag", "bin_url"
       ))
     )
     expect_equal(
@@ -83,7 +84,7 @@ test_that("load_replica_rds", {
 
   file_set_time(rep_files$rds, Sys.time() - 1/2  * oneday())
   expect_equal(
-    get_private(cmc)$load_replica_rds(oneday()),
+    suppressMessages(get_private(cmc)$load_replica_rds(oneday())),
     "This is it")
   expect_equal(get_private(cmc)$data, "This is it")
   expect_true(Sys.time() - get_private(cmc)$data_time < oneday())
@@ -115,14 +116,14 @@ test_that("load_primary_rds", {
   for (f in pri_files$pkgs$path) { mkdirp(dirname(f)); cat("x", file = f) }
   file_set_time(pri_files$pkgs$path, Sys.time() - 2  * oneday())
   expect_equal(
-    get_private(cmc)$load_primary_rds(oneday()),
+    suppressMessages(get_private(cmc)$load_primary_rds(oneday())),
     "This is it")
   expect_equal(get_private(cmc)$data, "This is it")
   expect_true(Sys.time() - get_private(cmc)$data_time < oneday())
 
   ## Replica was also updated
   expect_equal(
-    get_private(cmc)$load_replica_rds(oneday()),
+    suppressMessages(get_private(cmc)$load_replica_rds(oneday())),
     "This is it")
 })
 
@@ -157,8 +158,7 @@ test_that("load_primary_rds 3", {
 })
 
 test_that("load_primary_pkgs", {
-
-  withr::local_options(list(repos = NULL))
+  setup_fake_apps()
 
   dir.create(pri <- fs::path_norm(tempfile()))
   on.exit(unlink(pri, recursive = TRUE), add = TRUE)
@@ -174,7 +174,7 @@ test_that("load_primary_pkgs", {
 
   pri_files <- get_private(cmc)$get_cache_files("primary")
   mkdirp(dirname(pri_files$pkgs$path))
-  fs::file_copy(get_fixture("PACKAGES-mac.gz"), pri_files$pkgs$path[1])
+  fs::file_copy(test_path("fixtures/PACKAGES-mac.gz"), pri_files$pkgs$path[1])
   # if this fails, then we need to add a new R version to the list or
   # CRAN macOS platforms in platform.R
   expect_error(
@@ -182,7 +182,7 @@ test_that("load_primary_pkgs", {
     "Some primary PACKAGES files don't exist")
 
   for (i in utils::tail(seq_len(nrow(pri_files$pkgs)), -1)) {
-    fs::file_copy(get_fixture("PACKAGES-src.gz"), pri_files$pkgs$path[i])
+    fs::file_copy(test_path("fixtures/PACKAGES-src.gz"), pri_files$pkgs$path[i])
   }
   file_set_time(pri_files$pkgs$path, Sys.time() - 2 * oneday())
   expect_error(
@@ -190,7 +190,9 @@ test_that("load_primary_pkgs", {
     "Some primary PACKAGES files are outdated")
 
   file_set_time(pri_files$pkgs$path, Sys.time() - 1/2 * oneday())
-  res <- synchronise(get_private(cmc)$load_primary_pkgs(oneday()))
+  res <- suppressMessages(
+    synchronise(get_private(cmc)$load_primary_pkgs(oneday()))
+  )
   check_packages_data(res)
 
   ## RDS was updated as well
@@ -204,9 +206,7 @@ test_that("load_primary_pkgs", {
 })
 
 test_that("update_replica_pkgs", {
-
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
 
   dir.create(pri <- fs::path_norm(tempfile()))
   on.exit(unlink(pri, recursive = TRUE), add = TRUE)
@@ -215,12 +215,12 @@ test_that("update_replica_pkgs", {
 
   cmc <- cranlike_metadata_cache$new(pri, rep, "source", bioc = FALSE)
 
-  synchronise(get_private(cmc)$update_replica_pkgs())
+  suppressMessages(synchronise(get_private(cmc)$update_replica_pkgs()))
   rep_files <- get_private(cmc)$get_cache_files("replica")
   expect_true(all(file.exists(rep_files$pkgs$path)))
   expect_true(all(file.exists(rep_files$pkgs$etag)))
 
-  data <- get_private(cmc)$update_replica_rds()
+  data <- suppressMessages(get_private(cmc)$update_replica_rds())
   expect_identical(data, get_private(cmc)$data)
   check_packages_data(data)
 })
@@ -236,12 +236,12 @@ test_that("update_replica_rds", {
 
   rep_files <- get_private(cmc)$get_cache_files("replica")
   mkdirp(dirname(rep_files$pkgs$path))
-  fs::file_copy(get_fixture("PACKAGES-mac.gz"), rep_files$pkgs$path[1])
+  fs::file_copy(test_path("fixtures/PACKAGES-mac.gz"), rep_files$pkgs$path[1])
   for (i in utils::tail(seq_len(nrow(rep_files$pkgs)), -1)) {
-    fs::file_copy(get_fixture("PACKAGES-src.gz"), rep_files$pkgs$path[i])
+    fs::file_copy(test_path("fixtures/PACKAGES-src.gz"), rep_files$pkgs$path[i])
   }
 
-  data <- get_private(cmc)$update_replica_rds()
+  data <- suppressMessages(get_private(cmc)$update_replica_rds())
   expect_identical(get_private(cmc)$data, data)
   expect_true(get_private(cmc)$data_time > Sys.time() - oneminute())
   check_packages_data(data)
@@ -298,9 +298,7 @@ test_that("update_primary 2", {
 })
 
 test_that("update", {
-
-  skip_if_offline()
-  skip_on_cran()
+  setup_fake_apps()
 
   dir.create(pri <- fs::path_norm(tempfile()))
   on.exit(unlink(pri, recursive = TRUE), add = TRUE)
@@ -308,7 +306,7 @@ test_that("update", {
   on.exit(unlink(rep, recursive = TRUE), add = TRUE)
 
   cmc <- cranlike_metadata_cache$new(pri, rep, "source", bioc = FALSE)
-  data <- cmc$update()
+  data <- suppressMessages(cmc$update())
   check_packages_data(data)
 
   ## Data is loaded
@@ -335,15 +333,15 @@ test_that("update", {
 
   ## List
   expect_equal(as.list(data$pkgs), as.list(cmc$list()))
-  lst <- cmc$list(c("igraph", "MASS"))
-  expect_equal(sort(c("igraph", "MASS")), sort(unique(lst$package)))
+  lst <- cmc$list(c("pkg1", "pkg2"))
+  expect_equal(sort(c("pkg1", "pkg2")), sort(unique(lst$package)))
 
   ## Revdeps
-  rdeps <- cmc$revdeps("MASS")
-  expect_true("abc" %in% rdeps$package)
-  expect_true("abd" %in% rdeps$package)
+  rdeps <- cmc$revdeps("pkg1")
+  expect_true("pkg2" %in% rdeps$package)
+  expect_true("pkg3" %in% rdeps$package)
 
-  rdeps <- cmc$revdeps("MASS", recursive = FALSE)
-  expect_true("abc" %in% rdeps$package)
-  expect_false("abd" %in% rdeps$package)
+  rdeps <- cmc$revdeps("pkg1", recursive = FALSE)
+  expect_true("pkg2" %in% rdeps$package)
+  expect_false("pkg3" %in% rdeps$package)
 })
